@@ -1,9 +1,11 @@
 #![allow(missing_docs)]
 //! Errors
 
+mod ctrl;
 mod frame;
 mod handshake;
 
+pub use ctrl::CtrlError;
 pub use frame::FrameError;
 pub use handshake::HandshakeError;
 
@@ -11,6 +13,8 @@ use std::fmt::{Display, Formatter};
 
 #[derive(Debug)]
 pub enum Error {
+    Ctrl(CtrlError),
+
     Frame(FrameError),
 
     Handshake(HandshakeError),
@@ -28,6 +32,7 @@ impl Display for Error {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         use Error::*;
         match self {
+            Ctrl(e) => write!(f, "Control error: {}", e),
             Frame(e) => write!(f, "Frame error: {}", e),
             Handshake(e) => write!(f, "Handshake error: {}", e),
         }
@@ -39,6 +44,7 @@ impl std::error::Error for Error {
         use Error::*;
 
         match self {
+            Ctrl(e) => Some(e),
             Frame(e) => Some(e),
             Handshake(e) => Some(e),
         }
@@ -52,6 +58,10 @@ impl From<Error> for std::io::Error {
     }
 }
 
+impl From<CtrlError> for std::io::Error {
+    fn from(e: CtrlError) -> Self { Error::Ctrl(e).into() }
+}
+
 impl From<FrameError> for std::io::Error {
     fn from(e: FrameError) -> Self { Error::Frame(e).into() }
 }
