@@ -1,10 +1,12 @@
 //! Websocket handshake.
 
-pub mod client;
-pub mod server;
+pub mod key;
+pub mod request;
+pub mod response;
 
-pub use client::Request;
-pub use server::Response;
+pub use request::Request;
+pub use response::Response;
+pub use key::{new_sec_key, derive_accept_key};
 
 /// 32
 pub const MAX_ALLOW_HEADERS: usize = 32;
@@ -201,7 +203,7 @@ pub mod static_headers {
 
         (HEADER_SEC_WEBSOCKET_ACCEPT_NAME => b"sec-websocket-accept");
 
-        (HEADER_SEC_WEBSOCKET_VERSION_NAME => b"sec-webSocket-version");
+        (HEADER_SEC_WEBSOCKET_VERSION_NAME => b"sec-websocket-version");
     }
 
     // header value
